%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This file constructs the marginal tax rates series shown in Figure 1
% Karel Mertens, ``Marginal Tax Rates and Income, New Time Series Evidence''
% June 2013

% The series are in Figure1_AMTRs.xls
% 
% The ordering of the series is 
%   1    2    3    4    5     6     7     8       9         10
% YEAR  ALL1 ALL2 TOP1 TOP5 TOP10  TOP5-1 TOP10-5 BOTTOM99  BOTTOM90
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all; close all; 
addpath('auxiliary files');

%% Estimate AGI distributions per filing status
FitDistributions

%% Construct MTRS using method 1
MTRs_method1

%% Construct MTRS using method 2
MTRs_method2

%% Combine Series
DATA = xlsread('auxiliary files/existing_data.xlsx');
AMTRs_BRS = DATA(:,1:6);
SHARES    = DATA(:,7:9);
load MTRS1; load MTRS2;

YEARS = MTRS1(:,1);
sel=(AMTRs_BRS(:,1)>=min(YEARS))&(AMTRs_BRS(:,1)<=max(YEARS));
AMTR_BRS   = AMTRs_BRS(sel,:);
AMTR_BR    = [YEARS AMTR_BRS(:,2)];
dAMTR_BR   = [zeros(1,size(AMTR_BR,2))*NaN;diff(AMTR_BR)];
AMTR_S     = [YEARS AMTR_BRS(:,3:end)];
dAMTR_S    = [zeros(1,size(AMTR_S,2))*NaN;diff(AMTR_S)];
dMTRS1     = [zeros(1,size(MTRS1,2))*NaN;diff(MTRS1)];
dMTRS2     = [zeros(1,size(MTRS2,2))*NaN;diff(MTRS2)];
SHARES     = SHARES(sel,:);

 X = MTRS1(MTRS1(1:end,1)<1971,2:end);
 Y = AMTR_S(AMTR_S(1:end,1)<1971,2:end);
 sel=isnan(Y(:,1))==0&isnan(X(:,1))==0;
 
 for j = 1:4
    b = [ones(sum(sel),1) X(sel,j)]\Y(sel,j);
    XX  =[ones(length(X(:,j)),1) X(:,j)]*b;
    YY(:,j) = Y(:,j);
    YY(isnan(Y(:,j)),j) = XX(isnan(Y(:,j)));
 end
 
 X = MTRS2(MTRS2(1:end,1)<1971,2:end); 
 Y = YY;
 sel=isnan(Y(:,1))==0&isnan(X(:,1))==0;
 
 for j = 1:4
    b = [ones(sum(sel),1) X(sel,j)]\Y(sel,j);
    XX  =[ones(length(X(:,j)),1) X(:,j)]*b;
    YY(:,j) = Y(:,j);
    YY(isnan(Y(:,j)),j) = XX(isnan(Y(:,j)));
 end
 Y1 = YY;
 
 
 X = MTRS1(MTRS1(1:end,1)>1986,2:end);
 Y = AMTR_S(AMTR_S(1:end,1)>1986,2:end);
 YY=[];
 sel=isnan(Y(:,1))==0&isnan(X(:,1))==0;
 
 for j = 1:4
    b = [ones(sum(sel),1) X(sel,j)]\Y(sel,j);
    XX  =[ones(length(X(:,j)),1) X(:,j)]*b;
    YY(:,j) = Y(:,j);
    YY(isnan(Y(:,j)),j) = XX(isnan(Y(:,j)));
 end

 Y2=YY;
 
 AMTR1 = AMTR_S;
 AMTR1(1:size(Y1,1),2:1+size(Y1,2))=Y1;
 AMTR1(end-size(Y2,1)+1:end,2:1+size(Y2,2))=Y2;

 X = MTRS1(MTRS1(1:end,1)>1986,2:end);
 Y = AMTR_BR(AMTR_BR(1:end,1)>1986,2:end);
 YY=[];
 sel=isnan(Y(:,1))==0&isnan(X(:,1))==0;
 
 for j = 1
    b = [ones(sum(sel),1) X(sel,j)]\Y(sel,j);
    XX  =[ones(length(X(:,j)),1) X(:,j)]*b;
    YY(:,j) = Y(:,j);
    YY(isnan(Y(:,j)),j) = XX(isnan(Y(:,j)));
 end
 Y2=YY;
 
AMTR2 = AMTR_BR;
AMTR2(end-size(Y2,1)+1:end,2:1+size(Y2,2))=Y2;

AMTR = [AMTR2 AMTR1(:,2:end)];

%   1    2    3    4    5     6     7     8       9         10
% DATES ALL1 ALL2 TOP1 TOP5 TOP10  TOP5-1 TOP10-5 BOTTOM99  BOTTOM90;

s1  = SHARES(:,1);
s5  = SHARES(:,2);
s10 = SHARES(:,3);

AMTR_5to1  = (AMTR(:,5)-s1./s5.*AMTR(:,4)).*s5./(s5-s1);
AMTR_10to5 = (AMTR(:,6)-s5./s10.*AMTR(:,5)).*s10./(s10-s5);
AMTR_b99   = (AMTR(:,3)-s1./1.*AMTR(:,4)).*1./(1-s1);
AMTR_b90   = (AMTR(:,3)-s10./1.*AMTR(:,6)).*1./(1-s10);
AMTR=[AMTR(:,1:6) AMTR_5to1 AMTR_10to5 AMTR_b99 AMTR_b90];

xlswrite('Figure1_AMTRs',AMTR);

delete D.mat MTRS1.mat MTRS2.mat




